@@ -1,6 +1,6 @@
 package Log::Shiras::LogSpace;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare("v0.42.2");
+use version; our $VERSION = version->declare("v0.44.0");
 #~ use lib '../../';
 #~ use Log::Shiras::Unhide qw( :InternalLoGSpacE );
 ###InternalLoGSpacE	warn "You uncovered internal logging statements for Log::Shiras::LogSpace-$VERSION";
@@ -18,7 +18,7 @@ has log_space =>(
 		predicate	=> 'has_log_space',
 		default	=> sub{
 			my( $self ) = @_;
-			return ref $self;
+			return ref $self ? ref( $self ) : $self;# Handle class calls too
 		}
 	);
 
