@@ -1,15 +1,16 @@
 package Log::Shiras::Report::Test2Note;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare("v0.42.2");
+use version; our $VERSION = version->declare("v0.44.0");
+use 5.010;
+use utf8;
+use Moose;
+use namespace::autoclean;
+use MooseX::StrictConstructor;
 use Data::Dumper;
 use Test2::Tools::Basic;
-use strict;
-use warnings;
 
 #########1 Public Methods     3#########4#########5#########6#########7#########8#########9
 
-sub new{ bless {}, shift; }
-
 sub add_line{
 	shift;
 	my @input = ( ref $_[0]->{message} eq 'ARRAY' ) ? 
@@ -45,6 +46,8 @@ sub add_line{
 
 #########1 Phinish    	      3#########4#########5#########6#########7#########8#########9
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 # The preceding line will help the module return a true value
 
